# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"PostgresConnector": "01-postgres.ipynb",
         "execute": "01-postgres.ipynb",
         "create_schema": "01-postgres.ipynb",
         "drop_schema": "01-postgres.ipynb",
         "check_connection": "01-postgres.ipynb",
         "create_table": "01-postgres.ipynb",
         "download": "01-postgres.ipynb",
         "table_exists": "01-postgres.ipynb",
         "delete_table": "01-postgres.ipynb",
         "save": "01-postgres.ipynb",
         "get_schemas_list": "01-postgres.ipynb",
         "Driver": "03-notificator.ipynb",
         "get_driver": "03-notificator.ipynb",
         "WildberriesCategoryScrapper": "02-parser.ipynb",
         "get_category_df_from_page": "02-parser.ipynb",
         "update_page_num": "02-parser.ipynb",
         "run": "03-notificator.ipynb",
         "WildberriesSingleItemScrapper": "02-parser.ipynb",
         "get_params_df": "02-parser.ipynb",
         "get_sold_qty": "02-parser.ipynb",
         "get_seller_params": "02-parser.ipynb",
         "get_description": "02-parser.ipynb",
         "get_rates_vs_percentage": "02-parser.ipynb",
         "get_timestamp_from_row": "02-parser.ipynb",
         "get_first_feedback_timestamp": "02-parser.ipynb",
         "get_promotion": "02-parser.ipynb",
         "WildberriesMultipleItemScrapper": "02-parser.ipynb",
         "ShopstatSingleItemScrapper": "02-parser.ipynb",
         "authorize": "03-notificator.ipynb",
         "сheck_if_exists": "02-parser.ipynb",
         "ShopstatMultipleItemScrapper": "02-parser.ipynb",
         "TelegramNotificator": "03-notificator.ipynb",
         "send": "03-notificator.ipynb",
         "TimewebNotificator": "03-notificator.ipynb",
         "check_expiration_date": "03-notificator.ipynb",
         "check_servers": "03-notificator.ipynb"}

modules = ["core.py",
           "postgres.py",
           "parser.py",
           "notificator.py"]

doc_url = "https://mrtweety123.github.io/oceano_algos/"

git_url = "https://gitlab.com/oceano3/oceano_algos"

def custom_doc_links(name): return None
